<div id="create-action-form">
    <div class="form-group">
        <input type="text" class="form-control" name="name" placeholder="Name" ng-model="action.name" />
    </div>
    <div class="form-group">
        <input type="text" class="form-control" name="url" placeholder="/url" ng-model="action.url" />
    </div>
    <div class="row">
        <div class="form-group col-md-5">
            <select id="select-method" ng-model="action.method">
                <option value="">Select a method</option>
                <option value="GET">GET</option>
                <option value="POST">POST</option>
                <option value="DELETE">DELETE</option>
                <option value="PUT">PUT</option>
            </select>
        </div>
        <div class="form-group col-md-5">
            <select id="select-body" ng-model="action.contentType">
                <option value="application/json">application/json</option>
                <option value="application/xml">application/xml</option>
                <option value="text/plain">text/plain</option>
                <option value="text/html">text/html</option>
            </select>
        </div>
    </div>
    <div class="form-group">
        <textarea class="form-control" name="response-body" ng-model="action.body" rows="8"></textarea>
    </div>
    <button type="button" class="btn btn-block btn-save btn-primary" ng-click="save()">Save</button>
</div>