# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-11-12 04:12
from __future__ import unicode_literals

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Action',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=30)),
                ('url', models.CharField(max_length=50)),
                ('method', models.CharField(max_length=50)),
                ('contentType', models.CharField(max_length=100)),
                ('body', models.TextField()),
                ('created_at', models.DateTimeField(default=datetime.datetime(2017, 11, 12, 4, 12, 48, 881343))),
            ],
        ),
    ]
