<div id="view-action-dialog">
    <div class="row view-header">
        <span class="method-label method-label-post" ng-if="action.method == 'POST'">POST</span>
        <span class="method-label method-label-get" ng-if="action.method == 'GET'">GET</span>
        <span class="method-label method-label-put" ng-if="action.method == 'PUT'">PUT</span>
        <span class="method-label method-label-delete" ng-if="action.method == 'DELETE'">DELETE</span>
    </div>
    <div class="row view-name">
        <h4 ng-bind="action.name"></h4>
        <span class="url">([[ action.url ]])</span>
        <button class="btn btn-sm btn-outline-secondary" ng-click="copyURL()"><i class="ion ion-clipboard"></i>Copy the full url.</button>
        <button class="btn btn-sm btn-outline-info" ng-click="modify()"><i class="ion ion-compose"></i> Modify</button>
    </div>
    <div class="row view-body">
        <span class="content-type" ng-bind="action.contentType"></span>
    </div>
    <div class="row content">
        <pre><code class="json" ng-bind="action.body"></code></pre>
    </div>
</div>